# mmguero

**mmguero** is my personal collection of miscellaneous helper functions for Python.

## Contents

Run `mmguero` to get a list of the exported functions and classes, e.g.:

```bash
$ 🧰 mmguero v#.#.#
   Seth Grover's useful Python helpers

🌐 Project URLs:
   Homepage, https://github.com/mmguero/python-mmguero
   Issues, https://github.com/mmguero/python-mmguero/issues
   Repository, https://github.com/mmguero/python-mmguero.git

📦 Public functions and classes:
  ⚙️  aggressive_url_encode()
  ⚙️  append_to_file()
  ⚙️  ask_for_password()
  ⚙️  ask_for_string()
  🧱 AtomicInt
  ⚙️  base64_decode_if_prefixed()
  🧱 BoolOrExtra
  🧱 CaselessDictionary
  ⚙️  check_output_input()
  ⚙️  choose_multiple()
  ⚙️  choose_one()
  ⚙️  chown_recursive()
  ⚙️  clear_screen()
  ⚙️  contains_whitespace()
  🧱 ContextLockedOrderedDict
  ⚙️  count_lines_mmap()
  ⚙️  custom_make_translation()
  ⚙️  deep_get()
  ⚙️  deep_merge()
  ⚙️  deep_merge_in_place()
  ⚙️  deep_set()
  ⚙️  dict_search()
  ⚙️  display_message()
  ⚙️  display_program_box()
  ⚙️  download_to_file()
  ⚙️  dynamic_import()
  ⚙️  eprint()
  ⚙️  escape_ansi()
  ⚙️  escape_for_curl()
  ⚙️  evp_bytes_to_key()
  ⚙️  file_contents()
  ⚙️  flatten()
  ⚙️  get_function_name()
  ⚙️  get_iterable()
  ⚙️  get_primary_ip()
  ⚙️  get_verbosity_env_var_count()
  ⚙️  git_clone()
  ⚙️  json_obj_serializer()
  ⚙️  load_file_if_json()
  ⚙️  load_str_if_json()
  ⚙️  main()
  ⚙️  max_hash_value_by_key()
  ⚙️  max_hash_value_by_value()
  ⚙️  min_hash_value_by_key()
  ⚙️  min_hash_value_by_value()
  ⚙️  parse_curl_file()
  ⚙️  pop_line()
  ⚙️  pushd()
  ⚙️  remove_empty_folders()
  ⚙️  remove_falsy()
  ⚙️  remove_prefix()
  ⚙️  remove_suffix()
  ⚙️  rmtree_except()
  ⚙️  run_process()
  ⚙️  run_sub_process()
  ⚙️  same_file_or_dir()
  ⚙️  set_logging()
  ⚙️  sha256_sum()
  ⚙️  shakey_sum()
  ⚙️  size_human_format()
  ⚙️  str2bool()
  ⚙️  str2bool_or_extra()
  ⚙️  tablify()
  ⚙️  temporary_filename()
  ⚙️  test_socket()
  ⚙️  touch()
  ⚙️  unescape_for_curl()
  🧱 UserInputDefaultsBehavior
  🧱 UserInterfaceMode
  ⚙️  val2bool()
  ⚙️  which()
  ⚙️  yes_or_no()
```

## Installation

Using `pip`, to install the latest [release from PyPI](https://pypi.org/project/mmguero/):

```
python3 -m pip install -U mmguero
```

Or to install directly from GitHub:


```
python3 -m pip install -U 'git+https://github.com/mmguero/python-mmguero'
```

## Authors

* **Seth Grover** - *Initial work* - [mmguero](https://github.com/mmguero)

## License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.